@@ -45,13 +45,14 @@ using format 'LOG x.y:z LEVEL Actual message', which is described in detail
 in the tool documentation.
 """
 
-__version__ = '1.1.1'
+__version__ = '1.2'
 
 import re
 import sys
 from os.path import abspath
 
 from robot.api import ExecutionResult, ResultVisitor
+from robot.utils import Matcher
 
 
 def process_output(inpath, outpath=None, verbose=True):
@@ -148,6 +149,11 @@ class BaseChecker(object):
             pattern = '^%s$' % expected.replace('REGEXP:', '', 1).strip()
             if re.match(pattern, actual, re.DOTALL):
                 return True
+        if expected.startswith('GLOB:'):
+            pattern = expected.replace('GLOB:', '', 1).strip()
+            matcher = Matcher(pattern, caseless=False, spaceless=False)
+            if matcher.match(actual):
+                return True
         if expected.startswith('STARTS:'):
             start = expected.replace('STARTS:', '', 1).strip()
             if actual.startswith(start):
